==============
geocube README
==============

Tool to convert geopandas vector data into rasterized xarray data.


.. image:: https://img.shields.io/pypi/v/geocube.svg
        :target: https://pypi.python.org/pypi/geocube

.. image:: https://img.shields.io/travis/geocube/geocube.svg
        :target: https://travis-ci.org/geocube/geocube

.. image:: https://readthedocs.org/projects/geocube/badge/?version=latest
        :target: https://geocube.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/geocube/geocube/shield.svg
     :target: https://pyup.io/repos/github/geocube/geocube/
     :alt: Updates



* Free software: BSD-3 Clause license
* Documentation: https://geocube.readthedocs.io.

Credits
-------

This package was originally templated with with Cookiecutter_.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
